@@ -30,13 +30,14 @@ class KItemListContainerViewport : public QGraphicsView
     Q_OBJECT
 
 public:
-    KItemListContainerViewport(QGraphicsScene* scene, QWidget* parent);
+    KItemListContainerViewport(QGraphicsScene *scene, QWidget *parent);
+
 protected:
-    void wheelEvent(QWheelEvent* event) override;
+    void wheelEvent(QWheelEvent *event) override;
 };
 
-KItemListContainerViewport::KItemListContainerViewport(QGraphicsScene* scene, QWidget* parent) :
-    QGraphicsView(scene, parent)
+KItemListContainerViewport::KItemListContainerViewport(QGraphicsScene *scene, QWidget *parent)
+    : QGraphicsView(scene, parent)
 {
     setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
     setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
@@ -44,24 +45,24 @@ KItemListContainerViewport::KItemListContainerViewport(QGraphicsScene* scene, QW
     setFrameShape(QFrame::NoFrame);
 }
 
-void KItemListContainerViewport::wheelEvent(QWheelEvent* event)
+void KItemListContainerViewport::wheelEvent(QWheelEvent *event)
 {
     // Assure that the wheel-event gets forwarded to the parent
     // and not handled at all by QGraphicsView.
     event->ignore();
 }
 
-KItemListContainer::KItemListContainer(KItemListController* controller, QWidget* parent) :
-    QAbstractScrollArea(parent),
-    m_controller(controller),
-    m_horizontalSmoothScroller(nullptr),
-    m_verticalSmoothScroller(nullptr),
-    m_scroller(nullptr)
+KItemListContainer::KItemListContainer(KItemListController *controller, QWidget *parent)
+    : QAbstractScrollArea(parent)
+    , m_controller(controller)
+    , m_horizontalSmoothScroller(nullptr)
+    , m_verticalSmoothScroller(nullptr)
+    , m_scroller(nullptr)
 {
     Q_ASSERT(controller);
     controller->setParent(this);
 
-    QGraphicsView* graphicsView = new KItemListContainerViewport(new QGraphicsScene(this), this);
+    QGraphicsView *graphicsView = new KItemListContainerViewport(new QGraphicsScene(this), this);
     setViewport(graphicsView);
 
     m_horizontalSmoothScroller = new KItemListSmoothScroller(horizontalScrollBar(), this);
@@ -74,17 +75,13 @@ KItemListContainer::KItemListContainer(KItemListController* controller, QWidget*
         slotViewChanged(controller->view(), nullptr);
     }
 
-    connect(controller, &KItemListController::modelChanged,
-            this, &KItemListContainer::slotModelChanged);
-    connect(controller, &KItemListController::viewChanged,
-            this, &KItemListContainer::slotViewChanged);
+    connect(controller, &KItemListController::modelChanged, this, &KItemListContainer::slotModelChanged);
+    connect(controller, &KItemListController::viewChanged, this, &KItemListContainer::slotViewChanged);
 
     m_scroller = QScroller::scroller(viewport());
     m_scroller->grabGesture(viewport());
-    connect(controller, &KItemListController::scrollerStop,
-            this, &KItemListContainer::stopScroller);
-    connect(m_scroller, &QScroller::stateChanged,
-            controller, &KItemListController::slotStateChanged);
+    connect(controller, &KItemListController::scrollerStop, this, &KItemListContainer::stopScroller);
+    connect(m_scroller, &QScroller::stateChanged, controller, &KItemListController::slotStateChanged);
 }
 
 KItemListContainer::~KItemListContainer()
@@ -95,14 +92,14 @@ KItemListContainer::~KItemListContainer()
     m_controller = nullptr;
 }
 
-KItemListController* KItemListContainer::controller() const
+KItemListController *KItemListContainer::controller() const
 {
     return m_controller;
 }
 
 void KItemListContainer::setEnabledFrame(bool enable)
 {
-    QGraphicsView* graphicsView = qobject_cast<QGraphicsView*>(viewport());
+    QGraphicsView *graphicsView = qobject_cast<QGraphicsView *>(viewport());
     if (enable) {
         setFrameShape(QFrame::StyledPanel);
         graphicsView->setPalette(palette());
@@ -113,7 +110,7 @@ void KItemListContainer::setEnabledFrame(bool enable)
         // to the text color, so that enough contrast is given for all color
         // schemes
         QPalette p = graphicsView->palette();
-        p.setColor(QPalette::Active,   QPalette::Text, p.color(QPalette::Active,   QPalette::WindowText));
+        p.setColor(QPalette::Active, QPalette::Text, p.color(QPalette::Active, QPalette::WindowText));
         p.setColor(QPalette::Inactive, QPalette::Text, p.color(QPalette::Inactive, QPalette::WindowText));
         p.setColor(QPalette::Disabled, QPalette::Text, p.color(QPalette::Disabled, QPalette::WindowText));
         graphicsView->setPalette(p);
@@ -123,11 +120,11 @@ void KItemListContainer::setEnabledFrame(bool enable)
 
 bool KItemListContainer::enabledFrame() const
 {
-    const QGraphicsView* graphicsView = qobject_cast<QGraphicsView*>(viewport());
+    const QGraphicsView *graphicsView = qobject_cast<QGraphicsView *>(viewport());
     return graphicsView->autoFillBackground();
 }
 
-void KItemListContainer::keyPressEvent(QKeyEvent* event)
+void KItemListContainer::keyPressEvent(QKeyEvent *event)
 {
     // TODO: We should find a better way to handle the key press events in the view.
     // The reasons why we need this hack are:
@@ -135,19 +132,19 @@ void KItemListContainer::keyPressEvent(QKeyEvent* event)
     // 2. By default, the KItemListView does not have the keyboard focus in the QGraphicsScene, so
     //    simply sending the event to the QGraphicsView which is the KItemListContainer's viewport
     //    does not work.
-    KItemListView* view = m_controller->view();
+    KItemListView *view = m_controller->view();
     if (view) {
         QApplication::sendEvent(view, event);
     }
 }
 
-void KItemListContainer::showEvent(QShowEvent* event)
+void KItemListContainer::showEvent(QShowEvent *event)
 {
     QAbstractScrollArea::showEvent(event);
     updateGeometries();
 }
 
-void KItemListContainer::resizeEvent(QResizeEvent* event)
+void KItemListContainer::resizeEvent(QResizeEvent *event)
 {
     QAbstractScrollArea::resizeEvent(event);
     updateGeometries();
@@ -159,23 +156,21 @@ void KItemListContainer::scrollContentsBy(int dx, int dy)
     m_verticalSmoothScroller->scrollContentsBy(dy);
 }
 
-void KItemListContainer::wheelEvent(QWheelEvent* event)
+void KItemListContainer::wheelEvent(QWheelEvent *event)
 {
     if (event->modifiers().testFlag(Qt::ControlModifier)) {
         event->ignore();
         return;
     }
 
-    KItemListView* view = m_controller->view();
+    KItemListView *view = m_controller->view();
     if (!view) {
         event->ignore();
         return;
     }
 
-    const bool scrollHorizontally = (qAbs(event->angleDelta().y()) < qAbs(event->angleDelta().x())) ||
-                                    (!verticalScrollBar()->isVisible());
-    KItemListSmoothScroller* smoothScroller = scrollHorizontally ?
-                                              m_horizontalSmoothScroller : m_verticalSmoothScroller;
+    const bool scrollHorizontally = (qAbs(event->angleDelta().y()) < qAbs(event->angleDelta().x())) || (!verticalScrollBar()->isVisible());
+    KItemListSmoothScroller *smoothScroller = scrollHorizontally ? m_horizontalSmoothScroller : m_verticalSmoothScroller;
 
     smoothScroller->handleWheelEvent(event);
 }
@@ -186,27 +181,22 @@ void KItemListContainer::slotScrollOrientationChanged(Qt::Orientation current, Q
     updateSmoothScrollers(current);
 }
 
-void KItemListContainer::slotModelChanged(KItemModelBase* current, KItemModelBase* previous)
+void KItemListContainer::slotModelChanged(KItemModelBase *current, KItemModelBase *previous)
 {
     Q_UNUSED(current)
     Q_UNUSED(previous)
 }
 
-void KItemListContainer::slotViewChanged(KItemListView* current, KItemListView* previous)
+void KItemListContainer::slotViewChanged(KItemListView *current, KItemListView *previous)
 {
-    QGraphicsScene* scene = static_cast<QGraphicsView*>(viewport())->scene();
+    QGraphicsScene *scene = static_cast<QGraphicsView *>(viewport())->scene();
     if (previous) {
         scene->removeItem(previous);
-        disconnect(previous, &KItemListView::scrollOrientationChanged,
-                   this, &KItemListContainer::slotScrollOrientationChanged);
-        disconnect(previous, &KItemListView::scrollOffsetChanged,
-                   this, &KItemListContainer::updateScrollOffsetScrollBar);
-        disconnect(previous, &KItemListView::maximumScrollOffsetChanged,
-                   this, &KItemListContainer::updateScrollOffsetScrollBar);
-        disconnect(previous, &KItemListView::itemOffsetChanged,
-                   this, &KItemListContainer::updateItemOffsetScrollBar);
-        disconnect(previous, &KItemListView::maximumItemOffsetChanged,
-                   this, &KItemListContainer::updateItemOffsetScrollBar);
+        disconnect(previous, &KItemListView::scrollOrientationChanged, this, &KItemListContainer::slotScrollOrientationChanged);
+        disconnect(previous, &KItemListView::scrollOffsetChanged, this, &KItemListContainer::updateScrollOffsetScrollBar);
+        disconnect(previous, &KItemListView::maximumScrollOffsetChanged, this, &KItemListContainer::updateScrollOffsetScrollBar);
+        disconnect(previous, &KItemListView::itemOffsetChanged, this, &KItemListContainer::updateItemOffsetScrollBar);
+        disconnect(previous, &KItemListView::maximumItemOffsetChanged, this, &KItemListContainer::updateItemOffsetScrollBar);
         disconnect(previous, &KItemListView::scrollTo, this, &KItemListContainer::scrollTo);
         disconnect(m_horizontalSmoothScroller, &KItemListSmoothScroller::scrollingStopped, previous, &KItemListView::scrollingStopped);
         disconnect(m_verticalSmoothScroller, &KItemListSmoothScroller::scrollingStopped, previous, &KItemListView::scrollingStopped);
@@ -215,16 +205,11 @@ void KItemListContainer::slotViewChanged(KItemListView* current, KItemListView*
     }
     if (current) {
         scene->addItem(current);
-        connect(current, &KItemListView::scrollOrientationChanged,
-                this, &KItemListContainer::slotScrollOrientationChanged);
-        connect(current, &KItemListView::scrollOffsetChanged,
-                this, &KItemListContainer::updateScrollOffsetScrollBar);
-        connect(current, &KItemListView::maximumScrollOffsetChanged,
-                this, &KItemListContainer::updateScrollOffsetScrollBar);
-        connect(current, &KItemListView::itemOffsetChanged,
-                this, &KItemListContainer::updateItemOffsetScrollBar);
-        connect(current, &KItemListView::maximumItemOffsetChanged,
-                this, &KItemListContainer::updateItemOffsetScrollBar);
+        connect(current, &KItemListView::scrollOrientationChanged, this, &KItemListContainer::slotScrollOrientationChanged);
+        connect(current, &KItemListView::scrollOffsetChanged, this, &KItemListContainer::updateScrollOffsetScrollBar);
+        connect(current, &KItemListView::maximumScrollOffsetChanged, this, &KItemListContainer::updateScrollOffsetScrollBar);
+        connect(current, &KItemListView::itemOffsetChanged, this, &KItemListContainer::updateItemOffsetScrollBar);
+        connect(current, &KItemListView::maximumItemOffsetChanged, this, &KItemListContainer::updateItemOffsetScrollBar);
         connect(current, &KItemListView::scrollTo, this, &KItemListContainer::scrollTo);
         connect(m_horizontalSmoothScroller, &KItemListSmoothScroller::scrollingStopped, current, &KItemListView::scrollingStopped);
         connect(m_verticalSmoothScroller, &KItemListSmoothScroller::scrollingStopped, current, &KItemListView::scrollingStopped);
@@ -237,7 +222,7 @@ void KItemListContainer::slotViewChanged(KItemListView* current, KItemListView*
 
 void KItemListContainer::scrollTo(qreal offset)
 {
-    const KItemListView* view = m_controller->view();
+    const KItemListView *view = m_controller->view();
     if (view) {
         if (view->scrollOrientation() == Qt::Vertical) {
             m_verticalSmoothScroller->scrollTo(offset);
@@ -249,13 +234,13 @@ void KItemListContainer::scrollTo(qreal offset)
 
 void KItemListContainer::updateScrollOffsetScrollBar()
 {
-    const KItemListView* view = m_controller->view();
+    const KItemListView *view = m_controller->view();
     if (!view) {
         return;
     }
 
-    KItemListSmoothScroller* smoothScroller = nullptr;
-    QScrollBar* scrollOffsetScrollBar = nullptr;
+    KItemListSmoothScroller *smoothScroller = nullptr;
+    QScrollBar *scrollOffsetScrollBar = nullptr;
     int singleStep = 0;
     int pageStep = 0;
     int maximum = 0;
@@ -289,8 +274,7 @@ void KItemListContainer::updateScrollOffsetScrollBar()
 
     const int value = view->scrollOffset();
     if (smoothScroller->requestScrollBarUpdate(maximum)) {
-        const bool updatePolicy = (scrollOffsetScrollBar->maximum() > 0 && maximum == 0)
-                                  || horizontalScrollBarPolicy() == Qt::ScrollBarAlwaysOn;
+        const bool updatePolicy = (scrollOffsetScrollBar->maximum() > 0 && maximum == 0) || horizontalScrollBarPolicy() == Qt::ScrollBarAlwaysOn;
 
         scrollOffsetScrollBar->setSingleStep(singleStep);
         scrollOffsetScrollBar->setPageStep(pageStep);
@@ -307,13 +291,13 @@ void KItemListContainer::updateScrollOffsetScrollBar()
 
 void KItemListContainer::updateItemOffsetScrollBar()
 {
-    const KItemListView* view = m_controller->view();
+    const KItemListView *view = m_controller->view();
     if (!view) {
         return;
     }
 
-    KItemListSmoothScroller* smoothScroller = nullptr;
-    QScrollBar* itemOffsetScrollBar = nullptr;
+    KItemListSmoothScroller *smoothScroller = nullptr;
+    QScrollBar *itemOffsetScrollBar = nullptr;
     int singleStep = 0;
     int pageStep = 0;
     if (view->scrollOrientation() == Qt::Vertical) {
@@ -356,23 +340,19 @@ void KItemListContainer::updateGeometries()
         scrollbarSpacing = style()->pixelMetric(QStyle::PM_ScrollView_ScrollBarSpacing, &option, this);
     }
 
-    const int widthDec = verticalScrollBar()->isVisible()
-                         ? extra + scrollbarSpacing + style()->pixelMetric(QStyle::PM_ScrollBarExtent, &option, this)
-                         : extra;
+    const int widthDec = verticalScrollBar()->isVisible() ? extra + scrollbarSpacing + style()->pixelMetric(QStyle::PM_ScrollBarExtent, &option, this) : extra;
 
-    const int heightDec = horizontalScrollBar()->isVisible()
-                          ? extra + scrollbarSpacing + style()->pixelMetric(QStyle::PM_ScrollBarExtent, &option, this)
-                          : extra;
+    const int heightDec =
+        horizontalScrollBar()->isVisible() ? extra + scrollbarSpacing + style()->pixelMetric(QStyle::PM_ScrollBarExtent, &option, this) : extra;
 
-    const QRectF newGeometry(0, 0, rect.width() - widthDec,
-                             rect.height() - heightDec);
+    const QRectF newGeometry(0, 0, rect.width() - widthDec, rect.height() - heightDec);
     if (m_controller->view()->geometry() != newGeometry) {
         m_controller->view()->setGeometry(newGeometry);
 
         // Get the real geometry of the view again since the scrollbars
         // visibilities and the view geometry may have changed in re-layout.
-        static_cast<KItemListContainerViewport*>(viewport())->scene()->setSceneRect(m_controller->view()->geometry());
-        static_cast<KItemListContainerViewport*>(viewport())->viewport()->setGeometry(m_controller->view()->geometry().toRect());
+        static_cast<KItemListContainerViewport *>(viewport())->scene()->setSceneRect(m_controller->view()->geometry());
+        static_cast<KItemListContainerViewport *>(viewport())->viewport()->setGeometry(m_controller->view()->geometry().toRect());
 
         updateScrollOffsetScrollBar();
         updateItemOffsetScrollBar();
@@ -392,7 +372,7 @@ void KItemListContainer::updateSmoothScrollers(Qt::Orientation orientation)
 
 void KItemListContainer::updateScrollOffsetScrollBarPolicy()
 {
-    const KItemListView* view = m_controller->view();
+    const KItemListView *view = m_controller->view();
     Q_ASSERT(view);
     const bool vertical = (view->scrollOrientation() == Qt::Vertical);
 
@@ -407,8 +387,7 @@ void KItemListContainer::updateScrollOffsetScrollBarPolicy()
         newViewSize.rheight() += scrollBarInc;
     }
 
-    const Qt::ScrollBarPolicy policy = view->scrollBarRequired(newViewSize)
-                                       ? Qt::ScrollBarAlwaysOn : Qt::ScrollBarAsNeeded;
+    const Qt::ScrollBarPolicy policy = view->scrollBarRequired(newViewSize) ? Qt::ScrollBarAlwaysOn : Qt::ScrollBarAsNeeded;
     if (vertical) {
         setVerticalScrollBarPolicy(policy);
     } else {
