@@ -17,30 +17,34 @@
 
 QHash<QUrl, bool> DragAndDropHelper::m_urlListMatchesUrlCache;
 
-bool DragAndDropHelper::urlListMatchesUrl(const QList<QUrl>& urls, const QUrl& destUrl)
+bool DragAndDropHelper::urlListMatchesUrl(const QList<QUrl> &urls, const QUrl &destUrl)
 {
     auto iteratorResult = m_urlListMatchesUrlCache.constFind(destUrl);
     if (iteratorResult != m_urlListMatchesUrlCache.constEnd()) {
         return *iteratorResult;
     }
 
-    const bool destUrlMatches =
-        std::find_if(urls.constBegin(), urls.constEnd(), [destUrl](const QUrl& url) {
-            return url.matches(destUrl, QUrl::StripTrailingSlash);
-        }) != urls.constEnd();
+    const bool destUrlMatches = std::find_if(urls.constBegin(),
+                                             urls.constEnd(),
+                                             [destUrl](const QUrl &url) {
+                                                 return url.matches(destUrl, QUrl::StripTrailingSlash);
+                                             })
+        != urls.constEnd();
 
     return *m_urlListMatchesUrlCache.insert(destUrl, destUrlMatches);
 }
 
-KIO::DropJob* DragAndDropHelper::dropUrls(const QUrl& destUrl, QDropEvent* event, QWidget* window)
+KIO::DropJob *DragAndDropHelper::dropUrls(const QUrl &destUrl, QDropEvent *event, QWidget *window)
 {
-    const QMimeData* mimeData = event->mimeData();
+    const QMimeData *mimeData = event->mimeData();
     if (isArkDndMimeType(mimeData)) {
         const QString remoteDBusClient = mimeData->data(arkDndServiceMimeType());
         const QString remoteDBusPath = mimeData->data(arkDndPathMimeType());
 
-        QDBusMessage message = QDBusMessage::createMethodCall(remoteDBusClient, remoteDBusPath,
-                                                              QStringLiteral("org.kde.ark.DndExtract"), QStringLiteral("extractSelectedFilesTo"));
+        QDBusMessage message = QDBusMessage::createMethodCall(remoteDBusClient,
+                                                              remoteDBusPath,
+                                                              QStringLiteral("org.kde.ark.DndExtract"),
+                                                              QStringLiteral("extractSelectedFilesTo"));
         message.setArguments({destUrl.toDisplayString(QUrl::PreferLocalFile)});
         QDBusConnection::sessionBus().call(message);
     } else {
@@ -64,6 +68,5 @@ void DragAndDropHelper::clearUrlListMatchesUrlCache()
 
 bool DragAndDropHelper::isArkDndMimeType(const QMimeData *mimeData)
 {
-    return mimeData->hasFormat(arkDndServiceMimeType())
-            && mimeData->hasFormat(arkDndPathMimeType());
+    return mimeData->hasFormat(arkDndServiceMimeType()) && mimeData->hasFormat(arkDndPathMimeType());
 }
